RegexPatternSet class

Contains one or more regular expressions.

AWS WAF assigns an ARN to each RegexPatternSet that you create. To use a set in a rule, you provide the ARN to the Rule statement RegexPatternSetReferenceStatement.

Constructors

RegexPatternSet({String? arn, String? description, String? id, String? name, List<Regex>? regularExpressionList})
RegexPatternSet.fromJson(Map<String, dynamic> json)
factory

Properties

arn → String?
The Amazon Resource Name (ARN) of the entity.
final
description → String?
A description of the set that helps with identification. You cannot change the description of a set after you create it.
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
A unique identifier for the set. This ID is returned in the responses to create and list commands. You provide it to operations like update and delete.
final
name → String?
The name of the set. You cannot change the name after you create the set.
final
regularExpressionList → List<Regex>?
The regular expression patterns in the set.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited